#!/usr/bin/env python
###################
# whois - comparison of country lists
#
# Copyright Jean-Michel Philippe (c) 2006
#   <http://philipjm.free.fr/blog/>
#
# This is open source software released under the GPL license.
# The full text of this license is found in the file 'LICENSE',
# included with this source code package.
###################
# Usage:
#  just run this python script!
###################

###################
# importations
import os, whois, string, shutil, datetime

###################
# inits
WriteAccessErrorMsg = "! cannot write '%s', do you have sufficient rights?"

###################
# get the country lists
u = {}
for x in whois.IPCountryList:	# compute a list of unique names
	u[x] = 1
WhoisCountries = u.keys()
WhoisCountries.sort()
DBCountries = whois.geomap.CountryLocations.keys()

###################
# compare country lists
WhoisNotInDB = []
for Country in WhoisCountries:
	if Country in DBCountries:
		continue
	if Country in whois.geomap.CountryTranslation:
		if whois.geomap.CountryTranslation[Country] in DBCountries:
			continue
	WhoisNotInDB.append(Country)
WhoisNotInDB.sort()
DBNotInWhois = []
for Country in DBCountries:
	if Country not in WhoisCountries:
		DBNotInWhois.append(Country)
DBNotInWhois.sort()

###################
# eventually copy the country translation file
if os.path.isfile(whois.geomap.__TranslationFile__):
	try:
		Now = datetime.datetime.now().strftime('%Y%m%d-%H%M%S')
		ToFile = whois.geomap.__TranslationFile__ + '.' + Now
		shutil.copyfile(whois.geomap.__TranslationFile__, ToFile)
		print ">", whois.geomap.__TranslationFile__, "moved to", ToFile
	except:
		raise IOError, WriteAccessErrorMsg % ToFile

###################
# make the country translation file
try:
	FileId = open(whois.geomap.__TranslationFile__, 'w')
	FileId.write("""# whois country to geomap country nam translation
#
# Copy commented country names at the file end to the country
# they match below. If no match is found just keep it blank.
#
# e.g. :
# BAHAMAS = THE BAHAMAS

""")
	for Country in WhoisNotInDB:
		FileId.write(Country + ' = ' + os.linesep)
	if len(whois.geomap.CountryTranslation):
		FileId.write(os.linesep)
	for Country, TranslName in whois.geomap.CountryTranslation.items():
		FileId.write(Country + ' = ' + TranslName + os.linesep)
	FileId.write(os.linesep)
	for Country in DBNotInWhois:
		FileId.write('# ' + Country + os.linesep)
	FileId.close()
	print "> wrote country translation file '%s'" % whois.geomap.__TranslationFile__
except:
	raise IOError, WriteAccessErrorMsg % whois.geomap.__TranslationFile__

#print len(WhoisNotInDB)
#print "WhoisNotInDB =", WhoisNotInDB
#print len(DBNotInWhois)
#print "DBNotInWhois =", DBNotInWhois
